@@ -1,18 +1,19 @@
 package constants
 
 import (
-	apihelpers "github.com/openshift/hive/pkg/apis/helpers"
-	hivev1 "github.com/openshift/hive/pkg/apis/hive/v1"
+	apihelpers "github.com/openshift/hive/apis/helpers"
+	hivev1 "github.com/openshift/hive/apis/hive/v1"
 )
 
 const (
-	PlatformAWS       = "aws"
-	PlatformAzure     = "azure"
-	PlatformBaremetal = "baremetal"
-	PlatformGCP       = "gcp"
-	PlatformOpenStack = "openstack"
-	PlatformUnknown   = "unknown"
-	PlatformVSphere   = "vsphere"
+	PlatformAWS            = "aws"
+	PlatformAzure          = "azure"
+	PlatformBaremetal      = "baremetal"
+	PlatformAgentBaremetal = "agent-baremetal"
+	PlatformGCP            = "gcp"
+	PlatformOpenStack      = "openstack"
+	PlatformUnknown        = "unknown"
+	PlatformVSphere        = "vsphere"
 
 	mergedPullSecretSuffix = "merged-pull-secret"
 
@@ -165,6 +166,10 @@ const (
 	// that is a direct child of one of the valid domains.
 	ManagedDomainsFileEnvVar = "MANAGED_DOMAINS_FILE"
 
+	// SupportedContractImplementationsFileEnvVar if present, points to a simple json
+	// file that includes a list of contracts and their supported implementations.
+	SupportedContractImplementationsFileEnvVar = "SUPPORTED_CONTRACT_IMPLEMENTATIONS_FILE"
+
 	// ManagedDomainsVolumeName is the name of the volume that will point
 	// to the configmap containing the managed domain configuration.
 	ManagedDomainsVolumeName = "managed-domains"
@@ -190,6 +195,14 @@ const (
 	// path where we mount in the SSH key for connecting to the bare metal libvirt provisioning host.
 	LibvirtSSHPrivKeyPathEnvVar = "LIBVIRT_SSH_PRIV_KEY_PATH"
 
+	// BoundServiceAccountSigningKeyEnvVar contains the path to the bound service account signing key and
+	// is set in the install pod for AWS STS clusters.
+	BoundServiceAccountSigningKeyEnvVar = "BOUND_SA_SIGNING_KEY"
+
+	// BoundServiceAccountSigningKeyFile is the Secret key and filename where a
+	// ServiceAccount signing key will be projected into the install pod.
+	BoundServiceAccountSigningKeyFile = "bound-service-account-signing-key.key"
+
 	// FakeClusterInstallEnvVar is the environment variable Hive will set for the installmanager pod to request
 	// a fake install.
 	FakeClusterInstallEnvVar = "FAKE_INSTALL"
@@ -234,6 +247,12 @@ const (
 	// AWSSecretAccessKeySecretKey is the key we use in a Kubernetes Secret containing AWS credentials for the access key ID.
 	AWSSecretAccessKeySecretKey = "aws_secret_access_key"
 
+	// AWSConfigSecretKey is the key we use in a Kubernetes Secret containing AWS config.
+	AWSConfigSecretKey = "aws_config"
+
+	// AWSCredsMount is the location where the AWS credentials secret is mounted for uninstall pods.
+	AWSCredsMount = "/etc/aws-creds"
+
 	// TLSCrtSecretKey is the key we use in a Kubernetes Secret containing a TLS certificate.
 	TLSCrtSecretKey = "tls.crt"
 
@@ -272,15 +291,13 @@ const (
 	// VersionMajorMinorPatchLabel is a label applied to ClusterDeployments to show the version of the cluster
 	// in the form "[MAJOR].[MINOR].[PATCH]".
 	VersionMajorMinorPatchLabel = "hive.openshift.io/version-major-minor-patch"
+
 	// OvirtCredentialsName is the name of the oVirt credentials file.
 	OvirtCredentialsName = "ovirt-config.yaml"
 
 	// OvirtConfigEnvVar is the environment variable specifying the oVirt config path
 	OvirtConfigEnvVar = "OVIRT_CONFIG"
 
-	// AWSCredsMount is the location where the AWS credentials secret is mounted for uninstall pods.
-	AWSCredsMount = "/etc/aws-creds"
-
 	// InstallLogsUploadProviderEnvVar is used to specify which object store provider is being used.
 	InstallLogsUploadProviderEnvVar = "HIVE_INSTALL_LOGS_UPLOAD_PROVIDER"
 
@@ -315,6 +332,39 @@ const (
 	// that are previously claimed is no longer required and therefore should be removed/deprovisioned and removed
 	// from the pool.
 	ClusterClaimRemoveClusterAnnotation = "hive.openshift.io/remove-claimed-cluster-from-pool"
+
+	// HiveAWSServiceProviderCredentialsSecretRefEnvVar is the environment variable specifying what secret to use for
+	// assuming the service provider credentials for AWS clusters.
+	HiveAWSServiceProviderCredentialsSecretRefEnvVar = "HIVE_AWS_SERVICE_PROVIDER_CREDENTIALS_SECRET"
+
+	// HiveFeatureGatesEnabledEnvVar is the the environment variable specifying the comma separated list of
+	// feature gates that are enabled.
+	HiveFeatureGatesEnabledEnvVar = "HIVE_FEATURE_GATES_ENABLED"
+
+	// MachineManagementAnnotation
+	MachineManagementAnnotation = "hive.openshift.io/machine-management-cluster-name"
+
+	// AWSPrivateLinkControllerConfigFileEnvVar if present, points to a simple text
+	// file that includes configuration for aws-private-link-controller
+	AWSPrivateLinkControllerConfigFileEnvVar = "AWS_PRIVATELINK_CONTROLLER_CONFIG_FILE"
+
+	// HiveReleaseImageVerificationConfigMapNamespaceEnvVar is used to configure the config map that will be used
+	// to verify the release images being used for cluster deployments.
+	HiveReleaseImageVerificationConfigMapNamespaceEnvVar = "HIVE_RELEASE_IMAGE_VERIFICATION_CONFIGMAP_NS"
+	HiveReleaseImageVerificationConfigMapNameEnvVar      = "HIVE_RELEASE_IMAGE_VERIFICATION_CONFIGMAP_NAME"
+
+	// HiveConfigName is the one and only name for a HiveConfig supported in the cluster. Any others will be ignored.
+	HiveConfigName = "hive"
+
+	// ArgoCDEnvVar is the name of the environment variable used to tell the controller manager to enable ArgoCD integration.
+	ArgoCDEnvVar = "HIVE_ARGOCD"
+
+	// ArgoCDNamespaceEnvVar is the name of the environment variable used to specify the ArgoCD namespace
+	ArgoCDNamespaceEnvVar = "HIVE_ARGOCD_NAMESPACE"
+
+	// CreatedByHiveLabel is the label used for artifacts for external systems we integrate with
+	// that were created by Hive. The value for this label should be "true".
+	CreatedByHiveLabel = "hive.openshift.io/created-by"
 )
 
 // GetMergedPullSecretName returns name for merged pull secret name per cluster deployment
